.. yams documentation master file, created by
   sphinx-quickstart on Tue Jan  7 16:34:28 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to yams's documentation!
================================

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   yams


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
